import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg=select('svg');



const width=+svg.attr('width');
const height= +svg.attr('height');

const render= data => {
  const margin={top:20,right:20,bottom:20,left:100}
  const innerWidth=width-margin.left-margin.right
  const innerHeight=height-margin.top-margin.bottom
  
  const xScale=scaleLinear()
  							.domain([0,max(data,d=>d.population)])
  							.range([0,innerWidth])
  
  
  const yScale=scaleBand()
  							.domain(data.map(d=>d.country))
  							.range([0,innerHeight])
  							.padding(0.2)
  
  
  console.log(xScale.range())
  const g=svg.append('g')
  					.attr('transform',`translate(${margin.left},${margin.top})`)
  
  
  const xAxisTickFormat= number => format('.3s')(number)
  				.replace('G','B')
  const xAxis=axisBottom(xScale).tickFormat(xAxisTickFormat)
  
  
  
  g.append('g').call(axisLeft(yScale))
  		.select('.domain')
  		.remove()
  
  
  
  
  g.append('g').call(xAxis)
  		.attr('transform', `translate(0,${innerHeight})`)
  
  g.append('text')
  				.attr('y',0)
  				.attr('fill','black')
  				.text('Population')
  
	g.selectAll('rect').data(data)
  				.enter().append('rect')
  				.attr('y', d=> yScale(d.country))
  				.attr('width', d => xScale(d.population))
          .attr('height', yScale.bandwidth())
  
  g.append('text')
  		.attr('y',-10)
  		.text('Top 10 most populous countries')
}

csv('data.csv').then(data => {
				console.log(data)
  			data.forEach(d => {
        	d.population=+d.population *1000
        })
  			
  			render(data)
	})
